#! Flux3D 12.1



lastInstance = ApplicationMagneticACThermal3D(frequency='50',
                                              temperatureUnit=Unit['CELSIUS_DEGREE'],
                                              coilCoefficient=CoilCoefficientAutomatic(),
                                              formulationModel=MagneticACFormulationModelAutomatic(approximation=VectorPotentialApproximationEdge()),
                                              scalarVariableOrder=ScalarVariableAutomaticOrder(),
                                              vectorVariableOrder=VectorNodalVariableAutomaticOrder(),
                                              transientInitialization=TransientInitializationZeroInitialSolution())
     
lastInstance = VariationParameterFormula(name='abs_outer_tube',
                                         formula='0.2')
     
lastInstance = VariationParameterFormula(name='ABS_inner_TUBE',
                                         formula='0.8')
     
lastInstance = VariationParameterFormula(name='emis_outer_TUBE',
                                         formula='0.8')
     
lastInstance = VariationParameterFormula(name='conv_inner_TUBE',
                                         formula='100')
     
lastInstance = VariationParameterFormula(name='emis_INNER_TUBE',
                                         formula='0')
     
lastInstance = Material(name='steel',
                        propertyBH=PropertyBhNonlinearJmuknee(initialMur='600',
                        js='2',
                        knee='0.4',
                        equivalentHarmonicCurve=EquivalentBhUnmodified()),
                        propertyJE=PropertyJeLinear(rho='0.25e-6'),
                        thermalConductivity=KtIsotropic(k='47'),
                        specificHeat=RhoCpConstant(rhoCp='0.39e7'))
     
lastInstance = Material(name='copper',
                        propertyBH=PropertyBhLinear(mur='1'),
                        propertyJE=PropertyJeLinear(rho='2e-8'))
     
lastInstance = Material(name='inox_316',
                        propertyBH=PropertyBhLinear(mur='1'),
                        propertyJE=PropertyJeLinear(rho='7.4e-7'),
                        thermalConductivity=KtIsotropic(k='16.3'),
                        specificHeat=RhoCpConstant(rhoCp='3995920'),
                        volumicMass='7960')
     
lastInstance = RegionFace(name='convection',
                          magneticACThermal3D=MagneticACThermal3DFace(thermalType=Thermal3DFaceThermalExchanges(convection=Convection_surf_i(coefficient=coef_convection_i_uniforme(parameter='CONV_INNER_TUBE'),
                          infiniteTemperature=ioTemperature(temperature='20',
                          unit=Unit['CELSIUS_DEGREE']))),
                          magneticType=MagneticAC3DFaceInactive()),
                          color=Color['Green'],
                          visibility=Visibility['VISIBLE'])
     
lastInstance = RegionFace(name='radiation_steel',
                          magneticACThermal3D=MagneticACThermal3DFace(thermalType=Thermal3DFaceThermalExchanges(radiation=localRadiation(coefficients=coef_rayonnement_i_uniforme(emissivity='EMIS_OUTER_TUBE',
                          absorption='ABS_OUTER_TUBE'))),
                          magneticType=MagneticAC3DFaceInactive()),
                          color=Color['Red'],
                          visibility=Visibility['VISIBLE'])
     
lastInstance = RegionFace(name='RADIATION_inox',
                          magneticACThermal3D=MagneticACThermal3DFace(thermalType=Thermal3DFaceThermalExchanges(radiation=localRadiation(coefficients=coef_rayonnement_i_uniforme(emissivity='EMIS_INNER_TUBE',
                          absorption='ABS_INNER_TUBE'))),
                          magneticType=MagneticAC3DFaceInactive()),
                          color=Color['Red'],
                          visibility=Visibility['VISIBLE'])
     
lastInstance = RegionVolume(name='air',
                            magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeInactive(transparency='automatic'),
                            magneticType=MagneticAC3DVolumeVacuum()),
                            color=Color['Turquoise'],
                            visibility=Visibility['VISIBLE'])
     
lastInstance = CurrentStrandedCoil(name='Coil_component',
                                   rmsModulus='15',
                                   phase='0')
     
lastInstance = RegionVolume(name='coil',
                            magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeInactive(transparency='automatic'),
                            magneticType=MagneticAC3DVolumeCoilConductor(coilConductor=CoilConductor3D(turnNumber='250',
                            seriesParallel=AllInSeries(),
                            electricComponent=CoilConductor['COIL_COMPONENT'],
                            fillFactor='1'),
                            material=Material['COPPER'])),
                            color=Color['Red'],
                            visibility=Visibility['VISIBLE'])
     
lastInstance = RegionVolume(name='outer_tube',
                            magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeThermalConductor(transparency='automatic',
                            heat=VolumeHeatSourceJouleEffectValue()),
                            magneticType=MagneticAC3DVolumeSolidConductor(),
                            material=Material['STEEL']),
                            color=Color['Green'],
                            visibility=Visibility['VISIBLE'])
     
     
lastInstance = RegionVolume(name='inner_tube',
                            magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeThermalConductor(transparency='automatic'),
                            magneticType=MagneticAC3DVolumeMagnetic(),
                            material=Material['INOX_316']),
                            color=Color['Yellow'],
                            visibility=Visibility['VISIBLE'])
     
assignRegionToVolumes(volume=[Volume[8],
                      Volume[7],
                      Volume[6],
                      Volume[4],
                      Volume[2]],
                      region=RegionVolume['AIR'])
     
assignRegionToVolumes(volume=[Volume[5]],
                      region=RegionVolume['COIL'])
     
assignRegionToVolumes(volume=[Volume[3]],
                      region=RegionVolume['OUTER_TUBE'])
     
assignRegionToVolumes(volume=[Volume[1]],
                      region=RegionVolume['INNER_TUBE'])

FaceStructured[12].assignRegion(region=RegionFace['RADIATION_STEEL'])
     
FaceStructured[8].assignRegion(region=RegionFace['RADIATION_INOX'])
     
FaceStructured[7].assignRegion(region=RegionFace['CONVECTION'])
     
RegionVolume['COIL'].assignInputTerminals(inputTerminals=[Face[26]])
     
saveProjectAs('physbuilt.FLU')


